@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,8 @@ import importlib
 # PEP 396
 from .configuration import Version as __version__
 __all__ = ['list_formats', 'list_archive', 'extract_archive', 'test_archive',
-    'create_archive', 'diff_archives', 'search_archive', 'repack_archive']
+    'create_archive', 'diff_archives', 'search_archive', 'repack_archive',
+    'recompress_archive']
 
 
 # Supported archive commands
@@ -35,8 +36,8 @@ ArchiveFormats = (
     '7z', 'ace', 'adf', 'alzip', 'ape', 'ar', 'arc', 'arj',
     'bzip2', 'cab', 'chm', 'compress', 'cpio', 'deb', 'dms',
     'flac', 'gzip', 'iso', 'lrzip', 'lzh', 'lzip', 'lzma', 'lzop',
-    'rar', 'rpm', 'rzip', 'shar', 'shn', 'tar', 'xz',
-    'zip', 'zoo')
+    'rar', 'rpm', 'rzip', 'shar', 'shn', 'tar', 'vhd', 'xz',
+    'zip', 'zoo', 'zpaq')
 
 # Supported compressions (used with tar for example)
 # Note that all compressions must also be archive formats
@@ -76,10 +77,12 @@ ArchiveMimetypes = {
     'application/x-rzip': 'rzip',
     'application/x-shar': 'shar',
     'application/x-tar': 'tar',
+    'application/x-vhd': 'vhd',
     'application/x-xz': 'xz',
     'application/x-zip-compressed': 'zip',
     'application/x-zoo': 'zoo',
     'application/zip': 'zip',
+    'application/zpaq': 'zpaq',
     'audio/x-ape': 'ape',
     'audio/x-shn': 'shn',
     'audio/flac': 'flac',
@@ -127,10 +130,11 @@ ArchivePrograms = {
         'list': ('nomarch',),
     },
     'bzip2': {
-        'extract': ('pbzip2', 'lbzip2', 'bzip2', '7z', '7za', 'py_bz2'),
-        'test': ('pbzip2', 'lbzip2', 'bzip2', '7z', '7za'),
+        None: ('7z', '7za'),
+        'extract': ('pbzip2', 'lbzip2', 'bzip2', 'py_bz2'),
+        'test': ('pbzip2', 'lbzip2', 'bzip2'),
         'create': ('pbzip2', 'lbzip2', 'bzip2', 'py_bz2'),
-        'list': ('py_echo', '7z', '7za'),
+        'list': ('py_echo'),
     },
     'cab': {
         'extract': ('cabextract', '7z'),
@@ -222,6 +226,11 @@ ArchivePrograms = {
         'list': ('dpkg-deb', '7z'),
         'test': ('dpkg-deb', '7z'),
     },
+    'dms': {
+        'extract': ('xdms',),
+        'list': ('xdms',),
+        'test': ('xdms',),
+    },
     'lzop': {
         None: ('lzop',),
     },
@@ -245,6 +254,11 @@ ArchivePrograms = {
         'list': ('py_echo',),
         'create': ('shorten',),
     },
+    'vhd': {
+        'extract': ('7z',),
+        'list': ('7z',),
+        'test': ('7z',),
+    },
     'xz': {
         None: ('xz', '7z'),
         'extract': py_lzma,
@@ -253,10 +267,8 @@ ArchivePrograms = {
     'zoo': {
         None: ('zoo',),
     },
-    'dms': {
-        'extract': ('xdms',),
-        'list': ('xdms',),
-        'test': ('xdms',),
+    'zpaq': {
+        None: ('zpaq',),
     },
 }
 
@@ -441,7 +453,8 @@ def cleanup_outdir (outdir, archive):
     return outdir2, "`%s' (%s)" % (outdir2, msg)
 
 
-def _extract_archive(archive, verbosity=0, outdir=None, program=None, format=None, compression=None):
+def _extract_archive(archive, verbosity=0, interactive=True, outdir=None,
+                     program=None, format=None, compression=None):
     """Extract an archive.
     @return: output directory if command is 'extract', else None
     """
@@ -457,7 +470,7 @@ def _extract_archive(archive, verbosity=0, outdir=None, program=None, format=Non
     else:
         do_cleanup_outdir = False
     try:
-        cmdlist = get_archive_cmdlist(archive, compression, program, verbosity, outdir)
+        cmdlist = get_archive_cmdlist(archive, compression, program, verbosity, interactive, outdir)
         if cmdlist:
             # an empty command list means the get_archive_cmdlist() function
             # already handled the command (eg. when it's a builtin Python
@@ -479,8 +492,8 @@ def _extract_archive(archive, verbosity=0, outdir=None, program=None, format=Non
                 pass
 
 
-
-def _create_archive(archive, filenames, verbosity=0, program=None, format=None, compression=None):
+def _create_archive(archive, filenames, verbosity=0, interactive=True,
+                    program=None, format=None, compression=None):
     """Create an archive."""
     if format is None:
         format, compression = get_archive_format(archive)
@@ -494,7 +507,7 @@ def _create_archive(archive, filenames, verbosity=0, program=None, format=None,
         # the arc program mangles the archive name if it contains ".arc"
         origarchive = archive
         archive = util.tmpfile(dir=os.path.dirname(archive), suffix=".arc")
-    cmdlist = get_archive_cmdlist(archive, compression, program, verbosity, filenames)
+    cmdlist = get_archive_cmdlist(archive, compression, program, verbosity, interactive, filenames)
     if cmdlist:
         # an empty command list means the get_archive_cmdlist() function
         # already handled the command (eg. when it's a builtin Python
@@ -504,7 +517,8 @@ def _create_archive(archive, filenames, verbosity=0, program=None, format=None,
         shutil.move(archive, origarchive)
 
 
-def _handle_archive (archive, command, verbosity=0, program=None, format=None, compression=None):
+def _handle_archive(archive, command, verbosity=0, interactive=True,
+                    program=None, format=None, compression=None):
     """Test and list archives."""
     if format is None:
         format, compression = get_archive_format(archive)
@@ -515,7 +529,7 @@ def _handle_archive (archive, command, verbosity=0, program=None, format=None, c
     check_program_compression(archive, command, program, compression)
     get_archive_cmdlist = get_archive_cmdlist_func(program, command, format)
     # prepare keyword arguments for command list
-    cmdlist = get_archive_cmdlist(archive, compression, program, verbosity)
+    cmdlist = get_archive_cmdlist(archive, compression, program, verbosity, interactive)
     if cmdlist:
         # an empty command list means the get_archive_cmdlist() function
         # already handled the command (eg. when it's a builtin Python
@@ -546,7 +560,7 @@ def rmtree_log_error (func, path, exc):
     util.log_error(msg)
 
 
-def _diff_archives (archive1, archive2, verbosity=0):
+def _diff_archives (archive1, archive2, verbosity=0, interactive=True):
     """Show differences between two archives.
     @return 0 if archives are the same, else 1
     @raises: PatoolError on errors
@@ -570,7 +584,7 @@ def _diff_archives (archive1, archive2, verbosity=0):
         shutil.rmtree(tmpdir1, onerror=rmtree_log_error)
 
 
-def _search_archive(pattern, archive, verbosity=0):
+def _search_archive(pattern, archive, verbosity=0, interactive=True):
     """Search for given pattern in an archive."""
     grep = util.find_program("grep")
     if not grep:
@@ -584,7 +598,7 @@ def _search_archive(pattern, archive, verbosity=0):
         shutil.rmtree(tmpdir, onerror=rmtree_log_error)
 
 
-def _repack_archive (archive1, archive2, verbosity=0):
+def _repack_archive (archive1, archive2, verbosity=0, interactive=True):
     """Repackage an archive to a different format."""
     format1, compression1 = get_archive_format(archive1)
     format2, compression2 = get_archive_format(archive2)
@@ -605,7 +619,7 @@ def _repack_archive (archive1, archive2, verbosity=0):
         olddir = os.getcwd()
         os.chdir(path)
         try:
-            kwargs = dict(verbosity=verbosity)
+            kwargs = dict(verbosity=verbosity, interactive=interactive)
             if same_format:
                 # only compress since the format is the same
                 kwargs['format'] = compression2
@@ -616,79 +630,132 @@ def _repack_archive (archive1, archive2, verbosity=0):
         shutil.rmtree(tmpdir, onerror=rmtree_log_error)
 
 
+def _recompress_archive(archive, verbosity=0, interactive=True):
+    """Try to recompress an archive to smaller size."""
+    format, compression = get_archive_format(archive)
+    if compression:
+        # only recompress the compression itself (eg. for .tar.xz)
+        format = compression
+    tmpdir = util.tmpdir()
+    tmpdir2 = util.tmpdir()
+    base, ext = os.path.splitext(os.path.basename(archive))
+    archive2 = util.get_single_outfile(tmpdir2, base, extension=ext)
+    try:
+        # extract
+        kwargs = dict(verbosity=verbosity, format=format, outdir=tmpdir)
+        path = _extract_archive(archive, **kwargs)
+        # compress to new file
+        olddir = os.getcwd()
+        os.chdir(path)
+        try:
+            kwargs = dict(verbosity=verbosity, interactive=interactive, format=format)
+            files = tuple(os.listdir(path))
+            _create_archive(archive2, files, **kwargs)
+        finally:
+            os.chdir(olddir)
+        # check file sizes and replace if new file is smaller
+        filesize = util.get_filesize(archive)
+        filesize2 = util.get_filesize(archive2)
+        if filesize2 < filesize:
+            # replace file
+            os.remove(archive)
+            shutil.move(archive2, archive)
+            diffsize = filesize - filesize2
+            return "... recompressed file is now %s smaller." % util.strsize(diffsize)
+    finally:
+        shutil.rmtree(tmpdir, onerror=rmtree_log_error)
+        shutil.rmtree(tmpdir2, onerror=rmtree_log_error)
+    return "... recompressed file is not smaller, leaving archive as is."
+
+
 # the patool library API
 
-def extract_archive(archive, verbosity=0, outdir=None, program=None):
+def extract_archive(archive, verbosity=0, outdir=None, program=None, interactive=True):
     """Extract given archive."""
     util.check_existing_filename(archive)
     if verbosity >= 0:
         util.log_info("Extracting %s ..." % archive)
-    return _extract_archive(archive, verbosity=verbosity, outdir=outdir, program=program)
+    return _extract_archive(archive, verbosity=verbosity, interactive=interactive, outdir=outdir, program=program)
 
 
-def list_archive(archive, verbosity=1, program=None):
+def list_archive(archive, verbosity=1, program=None, interactive=True):
     """List given archive."""
     # Set default verbosity to 1 since the listing output should be visible.
     util.check_existing_filename(archive)
     if verbosity >= 0:
         util.log_info("Listing %s ..." % archive)
-    return _handle_archive(archive, 'list', verbosity=verbosity, program=program)
+    return _handle_archive(archive, 'list', verbosity=verbosity,
+      interactive=interactive, program=program)
 
 
-def test_archive(archive, verbosity=0, program=None):
+def test_archive(archive, verbosity=0, program=None, interactive=True):
     """Test given archive."""
     util.check_existing_filename(archive)
     if verbosity >= 0:
         util.log_info("Testing %s ..." % archive)
-    res = _handle_archive(archive, 'test', verbosity=verbosity, program=program)
+    res = _handle_archive(archive, 'test', verbosity=verbosity,
+        interactive=interactive, program=program)
     if verbosity >= 0:
         util.log_info("... tested ok.")
     return res
 
 
-def create_archive(archive, filenames, verbosity=0, program=None):
+def create_archive(archive, filenames, verbosity=0, program=None, interactive=True):
     """Create given archive with given files."""
     util.check_new_filename(archive)
     util.check_archive_filelist(filenames)
     if verbosity >= 0:
         util.log_info("Creating %s ..." % archive)
-    res = _create_archive(archive, filenames, verbosity=verbosity, program=program)
+    res = _create_archive(archive, filenames, verbosity=verbosity,
+                          interactive=interactive, program=program)
     if verbosity >= 0:
         util.log_info("... %s created." % archive)
     return res
 
 
-def diff_archives(archive1, archive2, verbosity=0):
+def diff_archives(archive1, archive2, verbosity=0, interactive=True):
     """Print differences between two archives."""
     util.check_existing_filename(archive1)
     util.check_existing_filename(archive2)
     if verbosity >= 0:
         util.log_info("Comparing %s with %s ..." % (archive1, archive2))
-    res = _diff_archives(archive1, archive2, verbosity=verbosity)
+    res = _diff_archives(archive1, archive2, verbosity=verbosity, interactive=interactive)
     if res == 0 and verbosity >= 0:
         util.log_info("... no differences found.")
 
 
-def search_archive(pattern, archive, verbosity=0):
+def search_archive(pattern, archive, verbosity=0, interactive=True):
     """Search pattern in archive members."""
     if not pattern:
         raise util.PatoolError("empty search pattern")
     util.check_existing_filename(archive)
     if verbosity >= 0:
         util.log_info("Searching %r in %s ..." % (pattern, archive))
-    res = _search_archive(pattern, archive, verbosity=verbosity)
+    res = _search_archive(pattern, archive, verbosity=verbosity, interactive=interactive)
     if res == 1 and verbosity >= 0:
         util.log_info("... %r not found" % pattern)
     return res
 
 
-def repack_archive (archive, archive_new, verbosity=0):
+def repack_archive (archive, archive_new, verbosity=0, interactive=True):
     """Repack archive to different file and/or format."""
     util.check_existing_filename(archive)
     util.check_new_filename(archive_new)
     if verbosity >= 0:
         util.log_info("Repacking %s to %s ..." % (archive, archive_new))
-    res = _repack_archive(archive, archive_new, verbosity=verbosity)
+    res = _repack_archive(archive, archive_new, verbosity=verbosity, interactive=interactive)
     if verbosity >= 0:
         util.log_info("... repacking successful.")
     return res
+
+
+def recompress_archive(archive, verbosity=0, interactive=True):
+    """Recompress an archive to hopefully smaller size."""
+    util.check_existing_filename(archive)
+    util.check_writable_filename(archive)
+    if verbosity >= 0:
+        util.log_info("Recompressing %s ..." % (archive,))
+    res = _recompress_archive(archive, verbosity=verbosity, interactive=interactive)
+    if res and verbosity >= 0:
+        util.log_info(res)
+    return 0
