@@ -1,4 +1,4 @@
-# Copyright (C) 2013-2014 Bastian Kleineidam
+# Copyright (C) 2013-2015 Bastian Kleineidam
 """
 Define basic configuration data like version or application name.
 """
@@ -7,10 +7,10 @@ import _patool_configdata as configdata
 Version = configdata.version
 ReleaseDate = configdata.release_date
 AppName = configdata.name
-App = AppName+" "+Version
+App = AppName+u" "+Version
 Author = configdata.author
 Maintainer = configdata.maintainer
-Copyright = "Copyright (C) 2004-2014 " + Author
+Copyright = u"Copyright (C) 2004-2015 " + Author
 Url = configdata.url
-SupportUrl = Url + "issues"
+SupportUrl = u"https://github.com/wummel/patool/issues/"
 Email = configdata.author_email
