@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,12 +20,12 @@ from . import extract_singlefile_standard, test_singlefile_standard
 extract_bzip2 = extract_singlefile_standard
 test_bzip2 = test_singlefile_standard
 
-def create_bzip2 (archive, compression, cmd, verbosity, filenames):
+def create_bzip2 (archive, compression, cmd, verbosity, interactive, filenames):
     """Create a BZIP2 archive."""
     cmdlist = [util.shell_quote(cmd)]
     if verbosity > 1:
         cmdlist.append('-v')
-    cmdlist.extend(['-c', '-z', '--'])
+    cmdlist.extend(['-c', '-z', '-9', '--'])
     cmdlist.extend([util.shell_quote(x) for x in filenames])
     cmdlist.extend(['>', util.shell_quote(archive)])
     return (cmdlist, {'shell': True})
