@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@ import mimetypes
 import tempfile
 import time
 import traceback
+import locale
 from . import configuration, ArchiveMimetypes, ArchiveCompressions
 try:
     from shutil import which
@@ -124,6 +125,7 @@ def add_mimedb_data(mimedb):
     add_mimetype(mimedb, 'application/x-dms', '.dms')
     add_mimetype(mimedb, 'application/x-zip-compressed', '.crx')
     add_mimetype(mimedb, 'application/x-shar', '.shar')
+    add_mimetype(mimedb, 'application/x-vhd', '.vhd')
     add_mimetype(mimedb, 'audio/x-ape', '.ape')
     add_mimetype(mimedb, 'audio/x-shn', '.shn')
     add_mimetype(mimedb, 'audio/flac', '.flac')
@@ -131,6 +133,7 @@ def add_mimedb_data(mimedb):
     add_mimetype(mimedb, 'application/x-iso9660-image', '.iso')
     add_mimetype(mimedb, 'application/zip', '.epub')
     add_mimetype(mimedb, 'application/zip', '.apk')
+    add_mimetype(mimedb, 'application/zpaq', '.zpaq')
 
 
 def add_mimetype(mimedb, mimetype, extension):
@@ -282,7 +285,12 @@ def guess_mime_file (filename):
             # ignore errors, as file(1) is only a fallback
             return mime, encoding
         mime2 = outparts[0].split(" ", 1)[0]
-        if mime2 in ('application/x-empty', 'application/octet-stream'):
+        # Some file(1) implementations return an empty or unknown mime type
+        # when the uncompressor program is not installed, other
+        # implementation return the original file type.
+        # The following detects both cases.
+        if (mime2 in ('application/x-empty', 'application/octet-stream') or
+            mime2 in Mime2Encoding):
             # The uncompressor program file(1) uses is not installed
             # or is not able to uncompress.
             # Try to get mime information from the file extension.
@@ -353,6 +361,7 @@ FileText2Mime = {
     "Monkey's Audio": "audio/x-ape",
     "FLAC audio bitstream data": "audio/flac",
     "MS Windows HtmlHelp Data": "application/x-chm",
+    "ZPAQ stream": "application/zpaq",
 }
 
 def guess_mime_file_text (file_prog, filename):
@@ -380,6 +389,12 @@ def check_existing_filename (filename, onlyfiles=True):
         raise PatoolError("`%s' is not a file" % filename)
 
 
+def check_writable_filename(filename):
+    """Ensure that the given filename is writable."""
+    if not os.access(filename, os.W_OK):
+        raise PatoolError("file `%s' is not writable" % filename)
+
+
 def check_new_filename (filename):
     """Check that filename does not already exist."""
     if os.path.exists(filename):
@@ -408,6 +423,31 @@ def set_mode (filename, flags):
             log_error("could not set mode flags for `%s': %s" % (filename, msg))
 
 
+def get_filesize(filename):
+    """Return file size in Bytes, or -1 on error."""
+    return os.path.getsize(filename)
+
+
+def strsize(b, grouping=True):
+    """Return human representation of bytes b. A negative number of bytes
+    raises a value error."""
+    if b < 0:
+        raise ValueError("Invalid negative byte number")
+    if b < 1024:
+        return u"%sB" % locale.format("%d", b, grouping)
+    if b < 1024 * 10:
+        return u"%sKB" % locale.format("%d", (b // 1024), grouping)
+    if b < 1024 * 1024:
+        return u"%sKB" % locale.format("%.2f", (float(b) / 1024), grouping)
+    if b < 1024 * 1024 * 10:
+        return u"%sMB" % locale.format("%.2f", (float(b) / (1024*1024)), grouping)
+    if b < 1024 * 1024 * 1024:
+        return u"%sMB" % locale.format("%.1f", (float(b) / (1024*1024)), grouping)
+    if b < 1024 * 1024 * 1024 * 10:
+        return u"%sGB" % locale.format("%.2f", (float(b) / (1024*1024*1024)), grouping)
+    return u"%sGB" % locale.format("%.1f", (float(b) / (1024*1024*1024)), grouping)
+
+
 def tmpdir (dir=None):
     """Return a temporary directory for extraction."""
     return tempfile.mkdtemp(suffix='', prefix='Unpack_', dir=dir)
@@ -536,7 +576,7 @@ def p7zip_supports_rar():
     # the subdirectory and codec name
     codecname = 'p7zip/Codecs/Rar29.so'
     # search canonical user library dirs
-    for libdir in ('/usr/lib', '/usr/local/lib'):
+    for libdir in ('/usr/lib', '/usr/local/lib', '/usr/lib64', '/usr/local/lib64', '/usr/lib/i386-linux-gnu', '/usr/lib/x86_64-linux-gnu'):
         fname = os.path.join(libdir, codecname)
         if os.path.exists(fname):
             return True
@@ -628,7 +668,7 @@ def link_or_copy(src, dst, verbosity=0):
         log_info("Copying %s -> %s" % (src, dst))
     try:
         os.link(src, dst)
-    except OSError:
+    except (AttributeError, OSError):
         try:
             shutil.copy(src, dst)
         except OSError as msg:
