@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2014 Bastian Kleineidam
+# Copyright (C) 2010-2015 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ class Test7z (ArchiveTest):
         self.archive_list('t.rpm')
         self.archive_list('t.deb')
         self.archive_list('t.iso')
+        self.archive_list('t.vhd')
         self.archive_extract('t.txt.gz', check=Content.Singlefile)
         self.archive_extract('t.txt.bz2', check=Content.Singlefile)
         self.archive_extract('t.txt.lzma', check=Content.Singlefile)
@@ -47,6 +48,7 @@ class Test7z (ArchiveTest):
         self.archive_extract('t.rpm', check=None)
         self.archive_extract('t.deb', check=None)
         self.archive_extract('t.iso')
+        self.archive_extract('t.vhd', check=None)
         self.archive_test('t.txt.gz')
         self.archive_test('t.txt.bz2')
         self.archive_test('t.txt.lzma')
@@ -58,7 +60,9 @@ class Test7z (ArchiveTest):
         self.archive_test('t.rpm')
         self.archive_test('t.deb')
         self.archive_test('t.iso')
+        self.archive_test('t.vhd')
         self.archive_create('t.txt.gz', check=Content.Singlefile)
+        self.archive_create('t.txt.bz2', check=Content.Singlefile)
 
     @needs_codec(program, 'rar')
     def test_7z_rar (self):
